@@ -186,6 +186,28 @@ register_argument_transform(
     from_wire={"X": dict_to_ndarray, "fit_data": fit_data_from_wire},
 )
 
+register_argument_transform(
+    "montecarlo.nisqAE.run_schedule",
+    to_wire={
+        "initial_circuit": quasar_to_string,
+        "iteration_circuit": quasar_to_string,
+    },
+    from_wire={
+        # "initial_circuit": string_to_quasar,
+        # "iteration_circuit": string_to_quasar,
+    },
+)
+
+register_argument_transform(
+    "montecarlo.nisqAE.run_unary",
+    to_wire={
+        "circuit": quasar_to_string,
+    },
+    from_wire={
+        # "circuit": string_to_quasar,
+    },
+)
+
 register_argument_transform(
     "qutils.qdot",
     to_wire={
@@ -200,6 +222,12 @@ register_argument_transform(
     },
 )
 
+register_argument_transform(
+    "qutils.create_qdot_circuit",
+    to_wire={"x": numeric_to_dict, "y": numeric_to_dict},
+    from_wire={"x": dict_to_numeric, "y": dict_to_numeric},
+)
+
 register_argument_transform(
     "qutils.qdist",
     to_wire={
